/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts;

import org.lexgrid.extension.cts.terminology.dto.CodeSystemIdAndVersions;
import org.lexgrid.extension.cts.terminology.dto.CompleteCodedConceptDescription;
import org.lexgrid.extension.cts.terminology.dto.ConceptDesignation;
import org.lexgrid.extension.cts.terminology.dto.ConceptId;
import org.lexgrid.extension.cts.terminology.dto.ConceptProperty;
import org.lexgrid.extension.cts.terminology.dto.RelatedCode;
import org.lexgrid.extension.cts.terminology.exceptions.BadlyFormedMatchText;
import org.lexgrid.extension.cts.terminology.exceptions.InvalidExpansionContext;
import org.lexgrid.extension.cts.terminology.exceptions.TimeoutError;
import org.lexgrid.extension.cts.terminology.exceptions.UnexpectedError;
import org.lexgrid.extension.cts.terminology.exceptions.UnknownCodeSystem;
import org.lexgrid.extension.cts.terminology.exceptions.UnknownConceptCode;
import org.lexgrid.extension.cts.terminology.exceptions.UnknownLanguageCode;
import org.lexgrid.extension.cts.terminology.exceptions.UnknownMatchAlgorithm;
import org.lexgrid.extension.cts.terminology.exceptions.UnknownMimeTypeCode;
import org.lexgrid.extension.cts.terminology.exceptions.UnknownPropertyCode;
import org.lexgrid.extension.cts.terminology.exceptions.UnknownRelationshipCode;

public interface BrowserOperations extends IdentifiableService {

/**
     * Return a list of supported match algorithms
     *
     * @return Return a list of supported match algorithms
     * @throws UnexpectedError
     */
java.lang.String[] getSupportedMatchAlgorithms();

    /**
     * Further expand the results of a previous expandCode call contextToExpand - node context from
     * prior expand code session Returns - list of expanded codes NOTE: if a sizeLimit has been
     * specified and the number of entries in the list is the same as the size limit, the caller
     * must presume that the list is incomplete.
     *
     * @param contextToExpand -
     *            node context from prior expand code session
     * @return - list of expanded codes
     * @throws InvalidExpansionContext
     * @throws TimeoutError
     * @throws UnexpectedError
     */
    RelatedCode[] expandCodeExpansionContext(byte[] contextToExpand);

    /**
     * List the children (or parents) of the supplied code expandConcept_id - Starting code system /
     * concept code If the concept code is omitted and only the code system is supplied expand code
     * returns all of the 'root' concept codes under the relationship.
     *
     * @param expandConceptId
     *            code system identifier and concept code to be expanded. If the relationship_code
     *            is "hasSubtype" and souceToTarget is true, the concept code can be omitted,
     *            meaning that we want all "root" concepts in the subtype relationship - all
     *            concepts that do not appear as the target of one or more hasSubtype relationships.
     * @param relationshipCode
     *            relationship to be expanded
     * @param sourceToTarget
     *            RUE means expand from source to target. FALSE means expand from target to source.
     * @param directRelationsOnly
     *            if TRUE or relationship_code is not transitive, only the direct targets (or
     *            sources if sourceToTarget is FALSE) of expandConcept_id are returned. If FALSE and
     *            relationship_code is transitive, descendants or ancestors are returned as well.
     * @param designationLanguageCode
     *            anguage that the returned concept designations should be in
     * @return RelatedCode[]
     * @throws UnknownLanguageCode
     * @throws UnknownRelationshipCode
     * @throws UnknownConceptCode
     * @throws UnknownCodeSystem
     * @throws TimeoutError
     * @throws UnexpectedError
     */
    RelatedCode[] lookupCodeExpansion(ConceptId expandConceptId, java.lang.String relationshipCode,
            boolean sourceToTarget, boolean directRelationsOnly,
            java.lang.String designationLanguageCode);
    /**
     * List the children (or parents) of the supplied code expandConcept_id - Starting code system /
     * concept code If the concept code is omitted and only the code system is supplied expand code
     * returns all of the 'root' concept codes under the relationship.
     *
     * @param expandConceptId
     *            code system identifier and concept code to be expanded. If the relationship_code
     *            is "hasSubtype" and souceToTarget is true, the concept code can be omitted,
     *            meaning that we want all "root" concepts in the subtype relationship - all
     *            concepts that do not appear as the target of one or more hasSubtype relationships.
     * @param relationshipCode
     *            relationship to be expanded
     * @param sourceToTarget
     *            RUE means expand from source to target. FALSE means expand from target to source.
     * @param directRelationsOnly
     *            if TRUE or relationship_code is not transitive, only the direct targets (or
     *            sources if sourceToTarget is FALSE) of expandConcept_id are returned. If FALSE and
     *            relationship_code is transitive, descendants or ancestors are returned as well.
     * @param designationLanguageCode
     *            anguage that the returned concept designations should be in
     * @param  timeOut
     * @param  sizeLimit
     * @return RelatedCode[]
     * @throws UnknownLanguageCode
     * @throws UnknownRelationshipCode
     * @throws UnknownConceptCode
     * @throws UnknownCodeSystem
     * @throws TimeoutError
     * @throws UnexpectedError
     */
    RelatedCode[] lookupCodeExpansion(ConceptId expandConceptId, java.lang.String relationshipCode,
            boolean sourceToTarget, boolean directRelationsOnly,
            java.lang.String designationLanguageCode,long timeOut,int sizeLimit);
    /**
     * List of code systems and versions supported by this service timeout - time limit for
     * operation to complete in milliseconds (0 means unlimited sizeLimit - maximum number of
     * elements to return (0 means unlimited) Returns - list of code systems NOTE: if a sizeLimit
     * has been specified and the number of entries in the list is the same as the size limit, the
     * caller must presume that the list is incomplete.
     *
     * @return list of code systems
     * @throws TimeoutError
     * @throws UnexpectedError
     */
    CodeSystemIdAndVersions[] getSupportedCodeSystems();

    /**
     * List of code systems and versions supported by this service timeout - time limit for
     * operation to complete in milliseconds (0 means unlimited sizeLimit - maximum number of
     * elements to return (0 means unlimited) Returns - list of code systems NOTE: if a sizeLimit
     * has been specified and the number of entries in the list is the same as the size limit, the
     * caller must presume that the list is incomplete.
     * @param timeLimit
     * @param sizeLimit
     * @return list of code systems
     * @throws TimeoutError
     * @throws UnexpectedError
     */
    CodeSystemIdAndVersions[] getSupportedCodeSystems(long timeLimit, int sizeLimit);

    /**
     * Retrieve a complete description of a concept code concept_id - concept to retrieve Returns -
     * complete description of the concept Exceptions UnknownCodeSystem - codeSystem is not
     * supported by the service UnknwonConceptCode - concept code is not valid in the code system
     *
     * @param conceptId -
     *            concept to retrieve
     * @return complete description of the concept
     * @throws UnknownConceptCode
     * @throws UnknownCodeSystem
     * @throws UnexpectedError
     */
    CompleteCodedConceptDescription lookupCompleteCodedConcept(ConceptId conceptId);

    /**
     * Return the concept codes with matching designations codeSystem_id - code system to query
     * matchText - Match string.
     *
     * @param codeSystemId -
     *            code system to query
     * @param matchText -
     *            Match string. Format depends upon the match algorithm.
     * @param matchAlgorithmCode -
     *            match algorithm to be used in the search
     * @param languageCode -
     *            language filter. If present, only designations / descriptions in this language are
     *            searched. (Default: all languages)
     * @param activeConceptsOnly -
     *            true means only active codes qualify. False means both. (Default: True)
     * @return a list of concept codes that match the supplied search criteria
     * @throws UnknownLanguageCode
     * @throws BadlyFormedMatchText
     * @throws UnknownMatchAlgorithm
     * @throws UnknownCodeSystem
     * @throws TimeoutError
     * @throws UnexpectedError
     */
    ConceptId[] lookupConceptCodesByDesignation(java.lang.String codeSystemId,
            java.lang.String matchText, java.lang.String matchAlgorithmCode,
            java.lang.String languageCode, boolean activeConceptsOnly);
    /**
     * Return the concept codes with matching designations codeSystem_id - code system to query
     * matchText - Match string.
     *
     * @param codeSystemId -
     *            code system to query
     * @param matchText -
     *            Match string. Format depends upon the match algorithm.
     * @param matchAlgorithmCode -
     *            match algorithm to be used in the search
     * @param languageCode -
     *            language filter. If present, only designations / descriptions in this language are
     *            searched. (Default: all languages)
     * @param activeConceptsOnly -
     *            true means only active codes qualify. False means both. (Default: True)
     * @return a list of concept codes that match the supplied search criteria
     * @param  timeOut
     * @param  sizeLimit
     * @throws UnknownLanguageCode
     * @throws BadlyFormedMatchText
     * @throws UnknownMatchAlgorithm
     * @throws UnknownCodeSystem
     * @throws TimeoutError
     * @throws UnexpectedError
     */
    ConceptId[] lookupConceptCodesByDesignation(java.lang.String codeSystemId,
            java.lang.String matchText, java.lang.String matchAlgorithmCode,
            java.lang.String languageCode, boolean activeConceptsOnly,long timeOut,int sizeLimit);
    /**
     * Return the concept codes with matching properties.
     *
     * @param codeSystemId -
     *            code system to query
     * @param matchText -
     *            Match string. Format depends upon the match algorithm.
     * @param matchAlgorithmCode -
     *            match algorithm to be used in the search
     * @param languageCode -
     *            language filter. If present, only properties in this language are searched.
     *            (Default: all languages)
     * @param activeConceptsOnly -
     *            true means only active codes qualify. False means both. (Default: True)
     * @param properties -
     *            List of property codes to search. (Default: All properties)
     * @param mimeTypes -
     *            only search properties with these mime types. (Default: all mime types)
     * @param timeout -
     *            time limit for operation to complete in milliseconds (0 means unlimited)
     * @param sizeLimit -
     *            maximum number of elements to return (0 means unlimited)
     * @return a list of concept codes that match the supplied search criteria
     * @throws UnknownLanguageCode
     * @throws UnknownPropertyCode
     * @throws BadlyFormedMatchText
     * @throws UnknownMatchAlgorithm
     * @throws UnknownMimeTypeCode
     * @throws UnknownCodeSystem
     * @throws TimeoutError
     * @throws UnexpectedError
     */
    ConceptId[] lookupConceptCodesByProperty(java.lang.String codeSystemId,
            java.lang.String matchText, java.lang.String matchAlgorithmCode,
            java.lang.String languageCode, boolean activeConceptsOnly,
            java.lang.String[] properties, java.lang.String[] mimeTypes);
    /**
     * Return the concept codes with matching properties.
     *
     * @param codeSystemId -
     *            code system to query
     * @param matchText -
     *            Match string. Format depends upon the match algorithm.
     * @param matchAlgorithmCode -
     *            match algorithm to be used in the search
     * @param languageCode -
     *            language filter. If present, only properties in this language are searched.
     *            (Default: all languages)
     * @param activeConceptsOnly -
     *            true means only active codes qualify. False means both. (Default: True)
     * @param properties -
     *            List of property codes to search. (Default: All properties)
     * @param mimeTypes -
     *            only search properties with these mime types. (Default: all mime types)
     * @param timeout -
     *            time limit for operation to complete in milliseconds (0 means unlimited)
     * @param sizeLimit -
     *            maximum number of elements to return (0 means unlimited)
     * @param  timeOut
     * @param  sizeLimit
     * @return a list of concept codes that match the supplied search criteria
     * @throws UnknownLanguageCode
     * @throws UnknownPropertyCode
     * @throws BadlyFormedMatchText
     * @throws UnknownMatchAlgorithm
     * @throws UnknownMimeTypeCode
     * @throws UnknownCodeSystem
     * @throws TimeoutError
     * @throws UnexpectedError
     */
    ConceptId[] lookupConceptCodesByProperty(java.lang.String codeSystemId,
            java.lang.String matchText, java.lang.String matchAlgorithmCode,
            java.lang.String languageCode, boolean activeConceptsOnly,
            java.lang.String[] properties, java.lang.String[] mimeTypes,long timeOut,int sizeLimit);
    /**
     * Return the designations of an individual concept that match the supplied criteria concept_id -
     * code system and concept code to match matchText - Match string.
     *
     * @param conceptCode -
     *            code system and concept code to match
     * @param matchText -
     *            Match string. Format depends upon the match algorithm
     * @param matchAlgorithmCode -
     *            match algorithm to use for matching
     * @param languageCode -
     *            if present, only match text of this language
     * @return Return the designations of an individual concept that match the supplied criteria
     * @throws UnknownLanguageCode
     * @throws BadlyFormedMatchText
     * @throws UnknownMatchAlgorithm
     * @throws UnknownConceptCode
     * @throws UnknownCodeSystem
     * @throws UnexpectedError
     */
    ConceptDesignation[] lookupDesignations(ConceptId conceptCode, java.lang.String matchText,
            java.lang.String matchAlgorithmCode, java.lang.String languageCode);

    /**
     * Return the properties of an individual concept that match the supplied criteria concept_id -
     * code system and concept code to match properties - if present, constrain the search to this
     * set of properties matchText - Match string.
     *
     * @param conceptId -
     *            code system and concept code to match
     * @param properties -
     *            if present, constrain the search to this set of properties
     * @param matchText -
     *            Match string. Format depends upon the match algorithm.
     * @param matchAlgorithmCode -
     *            match algorithm to use for matching
     * @param languageCode -
     *            if present, only return properties in this language
     * @param mimeTypes -
     *            constrain search to properties of these types
     * @return Return the properties of an individual concept that match the supplied criteria
     * @throws UnknownLanguageCode
     * @throws UnknownPropertyCode
     * @throws BadlyFormedMatchText
     * @throws UnknownMatchAlgorithm
     * @throws UnknownConceptCode
     * @throws UnknownMimeTypeCode
     * @throws UnknownCodeSystem
     * @throws UnexpectedError
     */
    ConceptProperty[] lookupProperties(ConceptId conceptId, java.lang.String[] properties,
            java.lang.String matchText, java.lang.String matchAlgorithmCode,
            java.lang.String languageCode, java.lang.String[] mimeTypes);
}