/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.impl;

import java.io.IOException;

import org.LexGrid.LexBIG.LexBIGService.LexBIGService;
import org.lexgrid.extension.cts.IdentifiableService;
import org.lexgrid.extension.cts.terminology.dto.CTSVersionId;

/**
 * Expects the values for the version information to be injected by some other framework or
 * component
 */
public class IdentifiableServicesImpl implements IdentifiableService {

    private CTSVersionId cTSVersion;

    private String serviceDescription;

    private String serviceName;

    private String serviceVersion;
    
    private LexBIGService lexBIGService;
    
    protected org.lexgrid.extension.cts.lexevs.util.template.LexEvsTemplate lexEVStemplate;

    IdentifiableServicesImpl() {
    	java.util.Properties props = new java.util.Properties();
        java.net.URL url = ClassLoader.getSystemResource("cts.properties");
        try {
			props.load(url.openStream());
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		cTSVersion = new CTSVersionId();
		
		cTSVersion.setMajor(new Short(props.getProperty("ctsMajorRelease")).shortValue());
		cTSVersion.setMinor(new Short(props.getProperty("ctsMinorRelease")).shortValue());
		
		serviceName = props.getProperty("serviceName");
		serviceDescription = props.getProperty("serviceDescription");
		serviceVersion = props.getProperty("serviceVersion");
    }
    
    public LexBIGService getLexBIGService() {
		return lexBIGService;
	}

	public void setLexBIGService(LexBIGService lexBIGService) {
		this.lexBIGService = lexBIGService;
		this.lexEVStemplate = new org.lexgrid.extension.cts.lexevs.util.template.LexEvsTemplate(lexBIGService);
	}

	public org.lexgrid.extension.cts.lexevs.util.template.LexEvsTemplate getLexEVSTemplate() {
		return lexEVStemplate;
	}

	public void setLexEVSTemplate(
			org.lexgrid.extension.cts.lexevs.util.template.LexEvsTemplate template) {
		this.lexEVStemplate = template;
	}

	@Override
    public CTSVersionId getCTSVersion() { 
        return cTSVersion;
    }

    @Override
    public String getServiceDescription() {
        return serviceDescription;
    }

    @Override
    public String getServiceName() { 
        return serviceName;
    }

    @Override
    public String getServiceVersion() { 
        return serviceVersion;
    }

    public void setCTSVersion(CTSVersionId version) {
        cTSVersion = version;
    }

    public void setServiceDescription(String serviceDescription) {
        this.serviceDescription = serviceDescription;
    }

    public void setServiceName(String serviceName) {
        this.serviceName = serviceName;
    }

    public void setServiceVersion(String serviceVersion) {
        this.serviceVersion = serviceVersion;
    }

}