/**
 * 
 */
package org.lexgrid.extension.cts.impl;

import org.LexGrid.LexBIG.DataModel.InterfaceElements.ExtensionDescription;
import org.LexGrid.LexBIG.Exceptions.LBException;
import org.LexGrid.LexBIG.Exceptions.LBParameterException;
import org.LexGrid.LexBIG.Impl.LexBIGServiceImpl;
import org.LexGrid.LexBIG.Impl.Extensions.ExtensionRegistryImpl;
import org.LexGrid.LexBIG.Impl.logging.LgLoggerIF;
import org.LexGrid.LexBIG.Impl.logging.LoggerFactory;
import org.LexGrid.LexBIG.LexBIGService.LexBIGService;
import org.LexGrid.annotations.LgClientSideSafe;
import org.LexGrid.commonTypes.Source;
import org.lexgrid.extension.cts.LexEVSCTSExtension;

/**
 * @author m004181
 *
 */
public class LexEVSCTSExtensionImpl implements LexEVSCTSExtension {
	
	private LexBIGService lbs_;
	private LexBigBrowserOperations browserOp_;
	private LexBigCodeMappingOperations codeMapOp_;
	private LexBigRuntimeOperations runtimeOp_;
	
	private static final long serialVersionUID = -1543872885685051947L;
    private final static String name_ = "LexEVSCTSExtension";
    private final static String description_ = "Common Terminology Services specification 1.2 implementation.";
    private final static String version_ = "1.0";
    private final static String provider_ = "MAYO";

   
    public LexEVSCTSExtensionImpl(){    	
    }
    
    public LexEVSCTSExtensionImpl(LexBIGService lexBigService){
    	lbs_ = lexBigService;
    }
    
    protected static LgLoggerIF getLogger() {
        return LoggerFactory.getLogger();
    }
       
	/* (non-Javadoc)
	 * @see org.lexgrid.cts.LexEVSCTSExtension#getVAPIBrowserOperations()
	 */
	public LexBigBrowserOperations getVAPIBrowserOperations() throws LBException {
		if (browserOp_ == null)
		{
			browserOp_ = new LexBigBrowserOperations();
			browserOp_.setLexBIGService(getLexBIGService());
		}
		
		return browserOp_;
	}

	/* (non-Javadoc)
	 * @see org.lexgrid.cts.LexEVSCTSExtension#getVAPICodeMappingOperations()
	 */
	public LexBigCodeMappingOperations getVAPICodeMappingOperations() {
		if (codeMapOp_ == null)
		{
			codeMapOp_ = new LexBigCodeMappingOperations();
			codeMapOp_.setLexBIGService(getLexBIGService());
		}
		
		return codeMapOp_;
	}

	/* (non-Javadoc)
	 * @see org.lexgrid.cts.LexEVSCTSExtension#getVAPIRuntimeOperations()
	 */
	public LexBigRuntimeOperations getVAPIRuntimeOperations() {
		if (runtimeOp_ == null)
		{
			runtimeOp_ = new LexBigRuntimeOperations();
			runtimeOp_.setLexBIGService(getLexBIGService());
		}
		
		return runtimeOp_;
	}

	@LgClientSideSafe
    public String getName() {
        getLogger().logMethod(new Object[] {});
        return name_;
    }

    @LgClientSideSafe
    public String getDescription() {
        getLogger().logMethod(new Object[] {});
        return description_;
    }

    @LgClientSideSafe
    public String getVersion() {
        getLogger().logMethod(new Object[] {});
        return version_;
    }

    @LgClientSideSafe
    public String getProvider() {
        getLogger().logMethod(new Object[] {});
        return provider_;
    }
    
    /**
     * Assign the associated LexBIGService instance.
     * <p>
     * Note: This method must be invoked by users of the distributed LexBIG API
     * to set the service to an EVSApplicationService object, allowing client
     * side implementations to use these convenience methods.
     */
    @LgClientSideSafe
    public void setLexBIGService(LexBIGService lbs) {
        lbs_ = lbs;
    }

    /**
     * Return the associated LexBIGService instance; lazy initialized as
     * required.
     */
    @LgClientSideSafe
    public LexBIGService getLexBIGService() {
        if (lbs_ == null)
            lbs_ = LexBIGServiceImpl.defaultInstance();
        return lbs_;
    }
    
	/**
	 * @param args
	 */
	public static void main(String[] args) {
		// TODO Auto-generated method stub

	}

}
