/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.impl;

import org.LexGrid.LexBIG.Exceptions.LBInvocationException;
import org.LexGrid.LexBIG.Exceptions.LBParameterException;
import org.LexGrid.LexBIG.LexBIGService.CodedNodeSet;
import org.LexGrid.LexBIG.LexBIGService.CodedNodeSet.ActiveOption;
import org.LexGrid.LexBIG.LexBIGService.CodedNodeSet.SearchDesignationOption;
import org.lexgrid.extension.cts.lexevs.util.matchalgorithm.MatchingAlgorithm;
import org.lexgrid.extension.cts.lexevs.util.template.Restrictions;
import org.lexgrid.extension.cts.terminology.exceptions.UnknownMatchAlgorithm;

/**
 * LexEVS {@link Restrictions} for the CTS lookupConceptCodesByDesignation service.
 */
public class LookupByDesignationRestrictions implements Restrictions {

    private MatchingAlgorithm matchAlgorithm;

    private String languageCode;

    private boolean activeConceptsOnly;

    private String matchText;

    /**
     * @param matchText
     * @param matchAlgorithm
     * @param languageCode
     * @param activeConceptsOnly
     */
    public LookupByDesignationRestrictions(String matchText, MatchingAlgorithm matchAlgorithm,
            String languageCode, boolean activeConceptsOnly) {
        this.matchAlgorithm = matchAlgorithm;
        this.languageCode = languageCode;
        this.activeConceptsOnly = activeConceptsOnly;
        this.matchText = matchText;
    }

    /*
     * (non-Javadoc)
     *
     * @see
     * com.gehc.ce.terminology.cts.impl.lexevs.util.template.Restrictions#addRestrictions(org.LexGrid
     * .LexBIG.LexBIGService.CodedNodeSet)
     */
    @Override
    public void addRestrictions(CodedNodeSet codeNodeSet) throws LBInvocationException,
            LBParameterException {
        if (matchAlgorithm != null) {
            matchText = matchAlgorithm.updateMatchText(matchText);
        } else {
            // spec has typo: says UnknownMatchCode
            throw new UnknownMatchAlgorithm();
        }

        codeNodeSet.restrictToMatchingDesignations(matchText, SearchDesignationOption.ALL,
                matchAlgorithm.getName(), languageCode);

        if (activeConceptsOnly) {
            codeNodeSet.restrictToStatus(ActiveOption.ACTIVE_ONLY, null);
        }
    }

}