/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.lexevs.adapters;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectOutputStream;

import org.LexGrid.LexBIG.DataModel.Core.AssociatedConcept;
import org.LexGrid.commonTypes.Text;
import org.LexGrid.concepts.Presentation;
import org.lexgrid.extension.cts.lexevs.util.LanguageUtil;
import org.lexgrid.extension.cts.terminology.dto.LexEvsExpansionContext;
import org.lexgrid.extension.cts.terminology.dto.RelatedCode;
import org.lexgrid.extension.cts.terminology.exceptions.UnexpectedError;

public final class AssociatedConceptToRelatedCodeAdapter {

    private AssociatedConceptToRelatedCodeAdapter() {}

    public static RelatedCode adapt(String association, AssociatedConcept associate,
            String languageCode, int depthLevel) {
        RelatedCode relatedCode = new RelatedCode();
        LexEvsExpansionContext context = new LexEvsExpansionContext();
        relatedCode.setConceptCode(associate.getConceptCode());
        relatedCode.setPathLength((short)depthLevel);
        Presentation[] presentations = associate.getReferencedEntry()
                .getPresentation();
        relatedCode.setDesignation("");
        for (Presentation presentation : presentations) {
            if (LanguageUtil.isMatchLanguage(languageCode, presentation)) {
            	Text propertyValue = presentation.getValue();
                relatedCode.setDesignation(propertyValue != null ? propertyValue.getContent() : null);
            }
        }

        if (associate.getSourceOf() != null || associate.getTargetOf() != null) {
            relatedCode.setCanExpand(true);
            context.setCodingSchemeId(associate.getCodingSchemeURI());
            context.setConceptCode(associate.getConceptCode());
            context.setDesignationLanguagecode(languageCode);
            context.setRelationshipCode(association.toString());
            context.setDepthLevel(relatedCode.getPathLength());

            //If sourceOF or targetOf is not null then directRelationsOnly had to have
            //been set to false
            context.setDirectRelationsOnly(false);

            if (associate.getSourceOf() == null) {
                context.setSourceToTarget(false);
            } else {
                context.setSourceToTarget(true);
            }

            try {
                ByteArrayOutputStream out = new ByteArrayOutputStream();
                ObjectOutputStream oos = new ObjectOutputStream(out);
                oos.writeObject(context);
                oos.flush();
                oos.close();
                out.close();
                relatedCode.setExpansionContext(out.toByteArray());
            } catch (IOException e) {

                throw new UnexpectedError(e);
            }

        }
        return relatedCode;
    }
}