/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.lexevs.adapters;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.LexGrid.LexBIG.DataModel.Collections.AssociatedConceptList;
import org.LexGrid.LexBIG.DataModel.Core.AssociatedConcept;
import org.LexGrid.LexBIG.DataModel.Core.Association;
import org.LexGrid.LexBIG.DataModel.Core.ResolvedConceptReference;
import org.lexgrid.extension.cts.terminology.dto.ConceptRelationship;

public final class AssociationToConceptRelationshipAdapter {

    private AssociationToConceptRelationshipAdapter(){
    }

    public static List<ConceptRelationship> adapt(Association association, ResolvedConceptReference rootConcept, boolean isSource) {

        List<ConceptRelationship> relationships = new ArrayList<ConceptRelationship>();

        AssociatedConceptList associatedConcepts = association
                .getAssociatedConcepts();
        Iterator<AssociatedConcept> associatedConceptsIterator = associatedConcepts
                .iterateAssociatedConcept();
        while (associatedConceptsIterator.hasNext()) {
            AssociatedConcept associatedConcept = associatedConceptsIterator
                    .next();
            ConceptRelationship relationship = new ConceptRelationship();
            relationship.setRelationQualifiers(null); // TODO: no relationship
            // qualifiers in LexBIG
            // NOTE: get the AssociatedConcept object from the Associate, and call getQualifiers
            relationship.setRelationshipCode(association.getAssociationName());
            if (isSource) {
                relationship.setTargetConceptId(ConceptReferenceToConceptIdAdapter.adapt(associatedConcept));
                relationship.setSourceConceptId(ConceptReferenceToConceptIdAdapter.adapt(rootConcept));
            } else {
                relationship.setSourceConceptId(ConceptReferenceToConceptIdAdapter.adapt(associatedConcept));
                relationship.setTargetConceptId(ConceptReferenceToConceptIdAdapter.adapt(rootConcept));
            }
            relationships.add(relationship);
        }
        return relationships;
    }
}