/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.lexevs.adapters;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import org.LexGrid.LexBIG.DataModel.Collections.CodingSchemeRenderingList;
import org.LexGrid.LexBIG.DataModel.Core.CodingSchemeSummary;
import org.LexGrid.LexBIG.DataModel.Core.CodingSchemeVersionOrTag;
import org.LexGrid.LexBIG.DataModel.InterfaceElements.CodingSchemeRendering;
import org.LexGrid.LexBIG.Exceptions.LBException;
import org.LexGrid.LexBIG.LexBIGService.LexBIGService;
import org.lexgrid.extension.cts.terminology.dto.CodeSystemIdAndVersions;

public final class CodingSchemeListToIdAndVersionsArrayAdapter {

    private CodingSchemeListToIdAndVersionsArrayAdapter() {}

    public static CodeSystemIdAndVersions[] adapt(LexBIGService service, CodingSchemeRenderingList codingSchemes) {

        Map<String, CodeSystemIdAndVersions> systems = new HashMap<String, CodeSystemIdAndVersions>();
        Iterator<CodingSchemeRendering> iterator = codingSchemes.iterateCodingSchemeRendering();

        while (iterator.hasNext()) {
            CodingSchemeRendering codingSchemeRendering = iterator.next();
            CodingSchemeSummary summary = codingSchemeRendering.getCodingSchemeSummary();
            String codingScheme = summary.getCodingSchemeURI();
            String version = summary.getRepresentsVersion();
            String copyRight = null;
            
            CodingSchemeVersionOrTag versionOrTag = new CodingSchemeVersionOrTag();
            versionOrTag.setVersion(version);
            
            try {
				copyRight = service.resolveCodingSchemeCopyright(codingScheme, versionOrTag);
			} catch (LBException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			
            addSummaryToList(systems, summary, copyRight);
        }

        return systems.values().toArray(new CodeSystemIdAndVersions[systems.size()]);
    }

    private static void addSummaryToList(Map<String, CodeSystemIdAndVersions> systems,
            CodingSchemeSummary summary, String copyRight) {
        CodeSystemIdAndVersions system = systems.get(summary.getCodingSchemeURI());
        if (system != null) {
            system.addVersion(summary.getRepresentsVersion());
        } else {
            system = CodingSchemeSummaryToIdAndVersionsAdapter.adapt(summary, copyRight);
            systems.put(system.getCodeSystemId(), system);
        }
    }
}