/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.lexevs.adapters;

import org.LexGrid.codingSchemes.CodingScheme;
import org.LexGrid.naming.SupportedAssociation;
import org.LexGrid.naming.SupportedLanguage;
import org.LexGrid.naming.SupportedProperty;
import org.lexgrid.extension.cts.terminology.dto.CodeSystemIdAndVersions;
import org.lexgrid.extension.cts.terminology.dto.CodeSystemInfo;

public final class CodingSchemeToCodeSystemInfoAdapter {
    private CodingSchemeToCodeSystemInfoAdapter() {}

    public static CodeSystemInfo adapt(CodingScheme codingScheme) {
        CodeSystemInfo codeSystemInfo = new CodeSystemInfo();
        CodeSystemIdAndVersions systemIdAndVerisons = new CodeSystemIdAndVersions();

        systemIdAndVerisons.setCodeSystemId(codingScheme.getCodingSchemeURI());
        systemIdAndVerisons.setCodeSystemName(codingScheme.getFormalName());

        String[] versionArray = { codingScheme.getRepresentsVersion() };
        systemIdAndVerisons.setCodeSystemVersions(versionArray);

        systemIdAndVerisons.setCopyright(codingScheme.getCopyright().getContent());
        codeSystemInfo.setCodeSystem(systemIdAndVerisons);

        codeSystemInfo.setCodeSystemDescription(codingScheme.getEntityDescription().getContent());
        codeSystemInfo.setFullName(codingScheme.getFormalName());

        SupportedLanguage[] supportedLanguages = codingScheme.getMappings().getSupportedLanguage();
        String[] languagesArray = new String[supportedLanguages.length];
        for (SupportedLanguage supportedLanguage : supportedLanguages) {
            int y = 0;
            String language = supportedLanguage.getLocalId();
            languagesArray[y] = language;
        }
        codeSystemInfo.setSupportedLanguages(languagesArray);

        SupportedProperty[] supportedProperties = codingScheme.getMappings().getSupportedProperty();
        String[] supportedProps = new String[supportedProperties.length];
        for (SupportedProperty supportedProperty : supportedProperties) {
            int x = 0;
            String supportedProp = supportedProperty.getLocalId();
            supportedProps[x] = supportedProp;
            x++;
        }
        codeSystemInfo.setSupportedProperties(supportedProps);

        SupportedAssociation[] supportedAssociations = codingScheme.getMappings()
                .getSupportedAssociation();
        String[] supportedRelations = new String[supportedAssociations.length];
        for (SupportedAssociation supportedAssociation : supportedAssociations) {
            int i = 0;
            String relations = supportedAssociation.getLocalId();
            supportedRelations[i] = relations;
            i++;
        }
        codeSystemInfo.setSupportedRelations(supportedRelations);

        return codeSystemInfo;

    }
}