/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.lexevs.adapters;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;

import org.LexGrid.LexBIG.DataModel.Core.ResolvedConceptReference;
import org.LexGrid.commonTypes.Property;
import org.LexGrid.concepts.Concept;
import org.LexGrid.concepts.Presentation;
import org.lexgrid.extension.cts.terminology.dto.CompleteCodedConceptDescription;
import org.lexgrid.extension.cts.terminology.dto.ConceptDesignation;
import org.lexgrid.extension.cts.terminology.dto.ConceptProperty;
import org.lexgrid.extension.cts.terminology.impl.ConceptStatus;

/**
 *
 */
public final class ConceptReferenceToCompleteConceptAdapter {

    private ConceptReferenceToCompleteConceptAdapter() {
    }

    public static CompleteCodedConceptDescription adapt(ResolvedConceptReference concept) {
        CompleteCodedConceptDescription completeConcept = new CompleteCodedConceptDescription();
        completeConcept.setCodeSystemVersion(concept.getCodingSchemeVersion());
        completeConcept.setConceptId(ConceptReferenceToConceptIdAdapter.adapt(concept));
        completeConcept.setConceptStatusCode(resolveStatus(concept));
        addCompleteDesignations(completeConcept, concept);
        addCompleteProperties(completeConcept, concept);
        return completeConcept;
    }

    /**
     * TODO status field is null in object, so for now hard-coding CTS sample status values. Need to
     * figure out what to do here. NOTE: status is optional... depends on coding system loaded.
     */
    private static String resolveStatus(ResolvedConceptReference resolvedConcept) {

        Concept concept = resolvedConcept.getReferencedEntry();
        String status = concept.getStatus();
        if (status == null) {
            status = concept.isIsActive() ? ConceptStatus.ACTIVE_STATUS.toString()
                    : ConceptStatus.RETIRED_STATUS.toString();
        }

        return status;
    }

    private static void addCompleteProperties(CompleteCodedConceptDescription completeConcept,
            ResolvedConceptReference resolvedConcept) {

        Concept concept = resolvedConcept.getReferencedEntry();
        
        List<Property> propList = new ArrayList();
        
        propList.addAll(safeArrayToList(concept.getComment()));
        propList.addAll(safeArrayToList(concept.getProperty()));
        propList.addAll(safeArrayToList(concept.getDefinition()));
        propList.addAll(safeArrayToList(concept.getPresentation()));
        
        List<ConceptProperty> ctsProperties = new ArrayList<ConceptProperty>();
        
        for (Iterator<Property> iterator = propList.iterator(); iterator.hasNext();) {
			Property property = (Property) iterator.next();
			ctsProperties.add(ConceptPropertyAdapter.adapt(property));
		}
        /*org.LexGrid.commonTypes.Property[] conceptProperties = concept.getProperty();
        List<ConceptProperty> ctsProperties = new ArrayList<ConceptProperty>();
        for (int i = 0; i < conceptProperties.length; i++) {
            ctsProperties.add(ConceptPropertyAdapter.adapt(conceptProperties[i]));
        }*/
        completeConcept.setHasProperties(ctsProperties.toArray(new ConceptProperty[ctsProperties
                .size()]));
    }

    /**
     * Convert an array to a list safely - if the array is null, then return an empty list.
     *
     * @param <T>
     * @param array
     * @return
     */
    private static <T> List<T> safeArrayToList(T[] array) {
        if (array == null) {
            return new ArrayList<T>();
        }
        List<T> list = Arrays.asList(array);
        return list;
    }
    
    private static void addCompleteDesignations(CompleteCodedConceptDescription completeConcept,
            ResolvedConceptReference resolvedConcept) {
        Concept concept = resolvedConcept.getReferencedEntry();
        Presentation[] presentations = concept.getPresentation();
        List<ConceptDesignation> designations = new ArrayList<ConceptDesignation>();
        for (int i = 0; i < presentations.length; i++) {
            designations.add(PresentationToConceptDesignationAdapter.adapt(presentations[i]));
        }
        completeConcept.setDesignatedBy(designations.toArray(new ConceptDesignation[designations
                .size()]));
    }
}