/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.lexevs.util;

import org.LexGrid.commonTypes.Property;

/**
 * Utility for dealing with language in LexEVS code.
 */
public final class LanguageUtil {

    private LanguageUtil() {}

    /**
     * Validates the presentation matches the given language. If no language is specified in either
     * the parameter or the presentation, then accept it (more info rather than less).
     *
     * @param languageCode
     * @param property
     * @return
     */
    public static boolean isMatchLanguage(String languageCode, Property property) {
        if (languageCode == null || property == null || property.getLanguage() == null) {
            return true;
        }

        if (property != null && languageCode.equals(property.getLanguage())) {
            return true;
        }

        return false;
    }

}