/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.lexevs.util.matchalgorithm;

import java.util.HashMap;
import java.util.Map;

public final class MatchingAlgorithmFactoryImpl implements
		MatchingAlgorithmFactory {

	private static MatchingAlgorithmFactoryImpl factory = null;

	private Map<String, MatchingAlgorithm> matchAlgorithmMap = new HashMap<String, MatchingAlgorithm>();

	private MatchingAlgorithmFactoryImpl() {
		
		MatchingAlgorithm exactMatchAlgorithm = new ExactMatch();
		exactMatchAlgorithm.setName("exactMatch");
		MatchingAlgorithm startesWithAlgorithm = new StartsWith();
		startesWithAlgorithm.setName("startsWith");
		MatchingAlgorithm luceneQueryMatchingAlgorithm = new LuceneQueryMatchingAlgorithm();
		luceneQueryMatchingAlgorithm.setName("LuceneQuery");
		MatchingAlgorithm doubleMetaPAlgorithm = new DoubleMetaphoneLuceneQuery();
		doubleMetaPAlgorithm.setName("DoubleMetaphoneLuceneQuery");
		MatchingAlgorithm containsAlgorithm = new ContainsMatchingAlgorithm();
		containsAlgorithm.setName("contains");
		MatchingAlgorithm regExpAlgorithm = new RegExpMatchAlgorithm();
		regExpAlgorithm.setName("RegExp");

		matchAlgorithmMap.put("exactMatch", exactMatchAlgorithm);
		matchAlgorithmMap.put("startsWith", startesWithAlgorithm);
		matchAlgorithmMap.put("LuceneQuery", luceneQueryMatchingAlgorithm);
		matchAlgorithmMap.put("DoubleMetaphoneLuceneQuery",
				doubleMetaPAlgorithm);
		matchAlgorithmMap.put("contains", containsAlgorithm);
		matchAlgorithmMap.put("RegExp", regExpAlgorithm);
	}

	public static MatchingAlgorithmFactoryImpl getInstance() {
		if (factory == null) {
			factory = new MatchingAlgorithmFactoryImpl();
		}
		return factory;
	}

	public MatchingAlgorithm getMatchingAlgorithm(String algorithmName) {

		return matchAlgorithmMap.get(algorithmName);
	}

	public Map<String, MatchingAlgorithm> getMatchAlgorithmMap() {
		return matchAlgorithmMap;
	}

	/*public void setMatchAlgorithmMap(
			Map<String, MatchingAlgorithm> matchAlgorithmMap) {
		this.matchAlgorithmMap = matchAlgorithmMap;
	}*/
}