/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.lexevs.util.template;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.LexGrid.LexBIG.DataModel.Collections.AssociatedConceptList;
import org.LexGrid.LexBIG.DataModel.Collections.AssociationList;
import org.LexGrid.LexBIG.DataModel.Core.AssociatedConcept;
import org.LexGrid.LexBIG.DataModel.Core.Association;

/**
 *
 */
public class AssociationExtractorImpl implements AssociationExtractor {

    /*
     * (non-Javadoc)
     *
     * @see
     * com.gehc.ce.terminology.cts.impl.lexevs.util.template.AssociationExtractor#extract(org.LexGrid
     * .LexBIG.DataModel.Collections.AssociationList,
     * com.gehc.ce.terminology.cts.impl.lexevs.util.template.AssociationMapper,
     * com.gehc.ce.terminology.cts.impl.lexevs.util.template.UpdateableAssociationGraphContext)
     */
    public <T> List<T> extract(AssociationList list, AssociationMapper<T> mapper,
            UpdateableAssociationGraphContext context) {

        List<T> results = new ArrayList<T>();
        if (list == null) {
            return results;
        }
        Iterator<Association> iterateAssociation = list.iterateAssociation();

        while (iterateAssociation.hasNext()) {
            Association association = iterateAssociation.next();
            extractAssociatedConcepts(mapper, results, association, association
                    .getAssociatedConcepts(), context);
        }
        return results;
    }

    /**
     *
     * @param <T>
     * @param mapper
     * @param results
     * @param association
     * @param associatedConcepts
     * @param context
     */
    protected <T> void extractAssociatedConcepts(AssociationMapper<T> mapper, List<T> results,
            Association association, AssociatedConceptList associatedConcepts,
            UpdateableAssociationGraphContext context) {
        Iterator<AssociatedConcept> iterateAssociatedConcept = associatedConcepts
                .iterateAssociatedConcept();
        while (iterateAssociatedConcept.hasNext()) {
            AssociatedConcept associatedConcept = iterateAssociatedConcept.next();
            context.setAssociation(association.getAssociationName());
            context.setAssociate(associatedConcept);
            T mappedObj = mapper.map(context);
            if (mappedObj != null) {
                results.add(mappedObj);
            }
        }
    }
}