/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.lexevs.util.template;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.LexGrid.LexBIG.DataModel.Collections.ResolvedConceptReferenceList;
import org.LexGrid.LexBIG.DataModel.Core.ResolvedConceptReference;
import org.lexgrid.extension.cts.lexevs.util.template.exceptions.LexEvsMapperException;

/**
 * Simple implementation of {@link ConceptExtractor}. Any null elements in the list are ignored.
 */
public class ConceptExtractorImpl implements ConceptExtractor {

    /*
     * (non-Javadoc)
     *
     * @see
     * com.gehc.ce.terminology.cts.impl.lexevs.util.template.ConceptExtractor#extract(com.gehc.ce
     * .terminology.cts.impl.lexevs.util.template.ConceptMapper,
     * org.LexGrid.LexBIG.DataModel.Collections.ResolvedConceptReferenceList)
     */
    @Override
    public <T> List<T> extract(ConceptMapper<T> mapper, ResolvedConceptReferenceList concepts) {

        if (mapper == null) {
            throw new LexEvsMapperException();
        }

        List<T> results = new ArrayList<T>();
        Iterator<ResolvedConceptReference> iterator = concepts.iterateResolvedConceptReference();
        mapElements(mapper, results, iterator);

        return results;
    }

    /**
     * For each element in the iterator, call the mapper and add the results.
     *
     * @param <T>
     * @param mapper
     * @param results
     * @param iterator
     */
    private <T> void mapElements(ConceptMapper<T> mapper, List<T> results,
            Iterator<ResolvedConceptReference> iterator) {
        while (iterator.hasNext()) {
            ResolvedConceptReference next = iterator.next();
            T mappedObj = mapper.map(next);
            if (mappedObj != null) {
                results.add(mappedObj);
            }
        }
    }

}