/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.lexevs.util.template;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;

import org.LexGrid.LexBIG.Exceptions.LBException;
import org.LexGrid.LexBIG.LexBIGService.CodedNodeGraph;
import org.LexGrid.LexBIG.LexBIGService.CodedNodeSet;
import org.lexgrid.extension.cts.lexevs.util.template.exceptions.LexEvsExceptionUtil;

/**
 * Uses Java Dynamic Proxies to suppress any of the resolve methods on CodedNodeGraphs and
 * CodedNodeSets. Useful when passing these objects to template methods responsible for other
 * operations on them.
 */
public class DynamicLexEvsProxyFactory implements LexEvsProxyFactory {

    protected static final String RESOLVE_METHOD_REGEX = "resolve.";

    /*
     * (non-Javadoc)
     *
     * @seecom.gehc.ce.terminology.cts.impl.lexevs.util.template.LexEvsProxyFactory#
     * getResolveSuppressingProxy(org.LexGrid.LexBIG.LexBIGService.CodedNodeGraph)
     */
    public CodedNodeGraph getResolveSuppressingProxy(CodedNodeGraph graph) {

        ClassLoader loader = DynamicLexEvsProxyFactory.class.getClassLoader();
        Class< ? >[] interfaces = new Class< ? >[] { CodedNodeGraph.class };
        return (CodedNodeGraph)Proxy.newProxyInstance(loader, interfaces,
                createResolveSuppressingHandler(graph));
    }

    /*
     * (non-Javadoc)
     *
     * @seecom.gehc.ce.terminology.cts.impl.lexevs.util.template.LexEvsProxyFactory#
     * getResolveSuppressingProxy(org.LexGrid.LexBIG.LexBIGService.CodedNodeSet)
     */
    public CodedNodeSet getResolveSuppressingProxy(CodedNodeSet set) {

        ClassLoader loader = DynamicLexEvsProxyFactory.class.getClassLoader();
        Class< ? >[] interfaces = new Class< ? >[] { CodedNodeSet.class };
        return (CodedNodeSet)Proxy.newProxyInstance(loader, interfaces,
                createResolveSuppressingHandler(set));
    }

    /**
     *
     * @param nodeOrGraph
     * @return
     */
    private InvocationHandler createResolveSuppressingHandler(final Object nodeOrGraph) {
        return new InvocationHandler() {

            @Override
            public Object invoke(Object proxy, Method method, Object[] args) throws Throwable {
                if (method.getName().matches(RESOLVE_METHOD_REGEX)) {
                    throw new UnsupportedOperationException("Not allowed to resolve here!");
                }
                try {
                    return method.invoke(nodeOrGraph, args);
                } catch (InvocationTargetException e) {
                    Throwable targetException = e.getCause();
                    if (targetException instanceof LBException) {
                        LexEvsExceptionUtil.wrapLBException((LBException)targetException);
                    }
                    throw targetException;
                }
            }

        };
    }
}