/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.lexevs.util.template;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.LexGrid.LexBIG.DataModel.Collections.AssociationList;
import org.LexGrid.LexBIG.DataModel.Collections.ResolvedConceptReferenceList;
import org.LexGrid.LexBIG.DataModel.Core.ResolvedConceptReference;

/**
 * Component to extract data from a CodedNodeGraph
 */
public class GraphExtractorImpl implements GraphExtractor {

    private AssociationExtractor associationExtractor = new AssociationExtractorImpl();

    /**
     * @return the associationExtractor
     */
    public AssociationExtractor getAssociationExtractor() {
        return associationExtractor;
    }

    /**
     * @param associationExtractor the associationExtractor to set
     */
    public void setAssociationExtractor(AssociationExtractor associationExtractor) {
        this.associationExtractor = associationExtractor;
    }

    /*
     * (non-Javadoc)
     *
     * @see com.gehc.ce.terminology.cts.impl.lexevs.util.template.GraphExtractor
     * #extractForward(org.LexGrid.LexBIG.DataModel.Collections.ResolvedConceptReferenceList,
     * com.gehc.ce.terminology.cts.impl.lexevs.util.template.AssociationMapper)
     */
    public <T> List<T> extractForward(ResolvedConceptReferenceList list, AssociationMapper<T> mapper) {
        return extractTemplate(list, mapper, createContext(true), new AssocListCallback() {
            public AssociationList getAssocList(ResolvedConceptReference concept) {
                return concept.getSourceOf();
            }
        });
    }

    /*
     * (non-Javadoc)
     *
     * @see com.gehc.ce.terminology.cts.impl.lexevs.util.template.GraphExtractor
     * #extractBackward(org.LexGrid.LexBIG.DataModel.Collections.ResolvedConceptReferenceList,
     * com.gehc.ce.terminology.cts.impl.lexevs.util.template.AssociationMapper)
     */
    public <T> List<T> extractBackward(ResolvedConceptReferenceList list,
            AssociationMapper<T> mapper) {

        return extractTemplate(list, mapper, createContext(false), new AssocListCallback() {
            public AssociationList getAssocList(ResolvedConceptReference concept) {
                return concept.getTargetOf();
            }
        });
    }

    /**
     * Both extractForward and extractBackward have the same logic except when getting the sourceOf
     * or targetOf AssociationList. This method has all the common code for both of those.
     *
     * @param <T>
     *            the type the mapper returns
     * @param list
     *            the list of resolved concept references returned by a CodedNodeGraph resolveAsList
     *            call.
     * @param mapper
     *            callback object responsible for converting the data from the given Association
     *            object into the desired return type.
     * @param listGetter
     *            callback to obtain the AssociationList to use the mapper against the members.
     * @param context
     *            info about association in graph and such for mapper
     * @return
     */
    private <T> List<T> extractTemplate(ResolvedConceptReferenceList list,
            AssociationMapper<T> mapper, UpdateableAssociationGraphContext context,
            AssocListCallback listGetter) {

        Iterator<ResolvedConceptReference> iterator = list.iterateResolvedConceptReference();
        while (iterator.hasNext()) {
            ResolvedConceptReference rConcept = iterator.next();

            AssociationList associations = listGetter.getAssocList(rConcept);
            return associationExtractor.extract(associations, mapper, context);
        }
        return new ArrayList<T>();
    }

    /**
     * Callback to obtain the AssociationList
     */
    private interface AssocListCallback {
        AssociationList getAssocList(ResolvedConceptReference concept);
    }

    private UpdateableAssociationGraphContext createContext(boolean isForward) {
        return new AssociationGraphContextImpl(isForward);
    }
}