/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.lexevs.util.template;

import java.util.List;

import org.LexGrid.LexBIG.DataModel.Core.ConceptReference;
import org.LexGrid.LexBIG.DataModel.Core.ResolvedConceptReference;
import org.LexGrid.LexBIG.LexBIGService.CodedNodeSet;
import org.LexGrid.LexBIG.LexBIGService.LexBIGService;

/**
 *
 */
public interface LexEvsOperations {

    /**
     * Gives access to the LexBIGService this wraps.
     *
     * @return
     */
    LexBIGService getService();

    /**
     * the maximum results allowed in any given query
     *
     * @return
     */
    int getMaxResults();

    /**
     * the maximum results allowed in any given query
     *
     * @param maxResults
     */
    void setMaxResults(int maxResults);

    /**
     * Find the concept matching the given parameters.
     *
     * @param code
     * @param codeSystem
     * @return
     */
    ResolvedConceptReference queryConcept(String code, String codeSystem);

    /**
     * Find the matching concept.
     *
     * @param code
     * @param codeSystem
     * @param resolveParams
     * @return
     */
    ResolvedConceptReference queryConcept(String code, String codeSystem,
            ResolveParams resolveParams);

    /**
     * Retrieve a list of concepts given the restrictions and resolve parameters and map the concept
     * data to the return type for the mapper.
     *
     * @param <T>
     *            the type returned by the mapper
     * @param mapper
     *            maps the concept data to a given type instance
     * @param restrictions
     *            query restrictions (filters, parameters, etc)
     * @param resolveParams
     *            parameters to control further the resolve.
     * @return
     */
    <T> List<T> queryConceptList(String codeSystem, ConceptMapper<T> mapper,
            Restrictions restrictions, ResolveParams resolveParams);

    /**
     * Retrieve a list of concepts given the restrictions and the default resolve parameters and map
     * the concept data to the return type for the mapper.
     *
     * @param <T>
     *            the type returned by the mapper
     * @param mapper
     *            maps the concept data to a given type instance
     * @param restrictions
     *            query restrictions (filters, parameters, etc)
     * @return
     */
    <T> List<T> queryConceptList(String codeSystem, ConceptMapper<T> mapper,
            Restrictions restrictions);

    /**
     * Find associations where given concept is the source and use the given mapper to convert
     * association data to the desired list of result objects.
     *
     * @param <T>
     * @param concept
     * @param mapper
     * @param restrictions
     * @return
     */
    <T> AssociationGraph<T> queryAssociations(ConceptReference concept,
            AssociationMapper<T> mapper, AssociationRestrictions restrictions);

    /**
     * Find associations for the given concept given the restrictions and resolutions.
     *
     * @param <T>
     * @param concept
     * @param mapper
     * @param restrictions
     * @param resolveParams
     * @return a list of a type matching the given mapper's return type with data from the
     *         associations.
     */
    <T> AssociationGraph<T> queryAssociations(ConceptReference concept,
            AssociationMapper<T> mapper, AssociationRestrictions restrictions,
            ResolveParams resolveParams);

    @Deprecated
    CodedNodeSet createNodeSet(final String codeSystem, Restrictions restrictions);

    /**
     * Check if given concept codes share a relationship.
     * @param codeSystemId
     * @param conceptCode
     * @param targetCode TODO
     * @param relationshipCode
     * @param directRelationsOnly
     * @return a boolean true if codes are related, false if not related.
     *
     */
    Boolean areCodesRelated(String codeSystemId, String conceptCode, String targetCode,
            String relationshipCode, boolean directRelationsOnly);
}