/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.lexevs.util.template;

import org.LexGrid.LexBIG.DataModel.Collections.LocalNameList;
import org.LexGrid.LexBIG.DataModel.Collections.ResolvedConceptReferenceList;
import org.LexGrid.LexBIG.DataModel.Collections.SortOptionList;
import org.LexGrid.LexBIG.DataModel.Core.ConceptReference;
import org.LexGrid.LexBIG.Exceptions.LBException;
import org.LexGrid.LexBIG.LexBIGService.CodedNodeGraph;
import org.LexGrid.LexBIG.LexBIGService.CodedNodeSet;
import org.LexGrid.LexBIG.LexBIGService.CodedNodeSet.PropertyType;
import org.LexGrid.LexBIG.Utility.Iterators.ResolvedConceptReferencesIterator;

/**
 * Object to execute the various resolve... methods.
 */
public class NodeResolverImpl implements NodeResolver {

    /*
     * (non-Javadoc)
     *
     * @see com.gehc.ce.terminology.cts.impl.lexevs.util.template.NodeResolver#resolveGraphAsList(org.LexGrid.LexBIG.LexBIGService.CodedNodeGraph,
     *      org.LexGrid.LexBIG.DataModel.Core.ConceptReference,
     *      com.gehc.ce.terminology.cts.impl.lexevs.util.template.Resolutions)
     */
    public ResolvedConceptReferenceList resolveGraphAsList(CodedNodeGraph nodeGraph,
            final ConceptReference focus, ResolveParams resolveParams) throws LBException {

        boolean forward = resolveParams.isResolveGraphForward();
        boolean back = resolveParams.isResolveGraphBackward();
        int entryDepth = resolveParams.getResolveGraphCodedEntryDepth();
        int assocDepth = resolveParams.getResolveGraphAssociationDepth();
        LocalNameList propNames = resolveParams.getPropertyNames();
        PropertyType[] propTypes = resolveParams.getPropertyTypes();
        SortOptionList sorting = resolveParams.getSortOptions();
        LocalNameList filtering = resolveParams.getFilterOptions();
        boolean keepLastAssocLevelUnresolved = resolveParams.isKeepLastAssociationLevelUnresolved();

        return nodeGraph.resolveAsList(focus, forward, back, entryDepth, assocDepth, propNames,
                propTypes, sorting, filtering, resolveParams.getMaxToReturn(),
                keepLastAssocLevelUnresolved);
    }

    /*
     * (non-Javadoc)
     *
     * @see com.gehc.ce.terminology.cts.impl.lexevs.util.template.NodeResolver#resolveToList(org.LexGrid.LexBIG.LexBIGService.CodedNodeSet,
     *      com.gehc.ce.terminology.cts.impl.lexevs.util.template.Resolutions)
     */
    public ResolvedConceptReferenceList resolveToList(CodedNodeSet nodeSet, ResolveParams resolveParams)
            throws LBException {

        SortOptionList sortOptions = resolveParams.getSortOptions();
        LocalNameList filterOptions = resolveParams.getFilterOptions();
        LocalNameList propertyNames = resolveParams.getPropertyNames();
        PropertyType[] propertyTypes = resolveParams.getPropertyTypes();
        boolean resolveSetConcepts = resolveParams.isResolveSetConcepts();
        int maxToReturn = resolveParams.getMaxToReturn();

        return nodeSet.resolveToList(sortOptions, filterOptions, propertyNames, propertyTypes,
                resolveSetConcepts, maxToReturn);
    }

    /*
     * (non-Javadoc)
     *
     * @see com.gehc.ce.terminology.cts.impl.lexevs.util.template.NodeResolver#resolve(org.LexGrid.LexBIG.LexBIGService.CodedNodeSet,
     *      com.gehc.ce.terminology.cts.impl.lexevs.util.template.Resolutions)
     */
    public ResolvedConceptReferencesIterator resolve(CodedNodeSet nodeSet, ResolveParams resoleParams)
            throws LBException {

        boolean resolveConcepts = resoleParams.isResolveSetConcepts();
        PropertyType[] propertyTypes = resoleParams.getPropertyTypes();
        LocalNameList propertyNames = resoleParams.getPropertyNames();
        LocalNameList filterOptions = resoleParams.getFilterOptions();
        SortOptionList sortOptions = resoleParams.getSortOptions();

        return nodeSet.resolve(sortOptions, filterOptions, propertyNames, propertyTypes,
                resolveConcepts);
    }

}