/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.lexevs.util.template;

import org.LexGrid.LexBIG.DataModel.Collections.LocalNameList;
import org.LexGrid.LexBIG.DataModel.Collections.SortOptionList;
import org.LexGrid.LexBIG.LexBIGService.CodedNodeSet.PropertyType;

/**
 * The LexEvs resolve* methods have a large number of parameters. For simple use of the API, some
 * are null, some are empty objects, and some values are most often used. All these parameters are
 * held in this object and the commonly used values are set as default.
 */
public class ResolveParams {

    public static final int DEFAULT_MAX_RESULTS = 500;


    private boolean resolveGraphForward = true;

    private boolean resolveGraphBackward;

    private int resolveGraphCodedEntryDepth = 1;

    private int resolveGraphAssociationDepth = 1;

    private LocalNameList propertyNames;

    private PropertyType[] propertyTypes;

    private SortOptionList sortOptions;

    private LocalNameList filterOptions;

    private int maxToReturn = DEFAULT_MAX_RESULTS;

    private boolean keepLastAssociationLevelUnresolved;

    private boolean resolveSetConcepts = true;

    public ResolveParams() {}

    public ResolveParams(int maxResultsToReturn) {
        this.maxToReturn = maxResultsToReturn;
    }

    public boolean isResolveSetConcepts() {
        return resolveSetConcepts;
    }

    public void setResolveSetConcepts(boolean resolveSetConcepts) {
        this.resolveSetConcepts = resolveSetConcepts;
    }

    public boolean isResolveGraphForward() {
        return resolveGraphForward;
    }

    public void setResolveGraphForward(boolean resolveGraphForward) {
        this.resolveGraphForward = resolveGraphForward;
    }

    public boolean isResolveGraphBackward() {
        return resolveGraphBackward;
    }

    public void setResolveGraphBackward(boolean resolveGraphBackward) {
        this.resolveGraphBackward = resolveGraphBackward;
    }

    public int getResolveGraphCodedEntryDepth() {
        return resolveGraphCodedEntryDepth;
    }

    public void setResolveGraphCodedEntryDepth(int resolveGraphCodedEntryDepth) {
        this.resolveGraphCodedEntryDepth = resolveGraphCodedEntryDepth;
    }

    public int getResolveGraphAssociationDepth() {
        return resolveGraphAssociationDepth;
    }

    public void setResolveGraphAssociationDepth(int resolveGraphAssociationDepth) {
        this.resolveGraphAssociationDepth = resolveGraphAssociationDepth;
    }

    public LocalNameList getPropertyNames() {
        return propertyNames;
    }

    public void setPropertyNames(LocalNameList propertyNames) {
        this.propertyNames = propertyNames;
    }

    public PropertyType[] getPropertyTypes() {
        return propertyTypes;
    }

    public void setPropertyTypes(PropertyType[] propertyTypes) {
        this.propertyTypes = propertyTypes;
    }

    public SortOptionList getSortOptions() {
        return sortOptions;
    }

    public void setSortOptions(SortOptionList sortOptions) {
        this.sortOptions = sortOptions;
    }

    public LocalNameList getFilterOptions() {
        return filterOptions;
    }

    public void setFilterOptions(LocalNameList filterOptions) {
        this.filterOptions = filterOptions;
    }

    public int getMaxToReturn() {
        return maxToReturn;
    }

    public void setMaxToReturn(int maxToReturn) {
        this.maxToReturn = maxToReturn;
    }

    public boolean isKeepLastAssociationLevelUnresolved() {
        return keepLastAssociationLevelUnresolved;
    }

    public void setKeepLastAssociationLevelUnresolved(boolean keepLastAssociationLevelUnresolved) {
        this.keepLastAssociationLevelUnresolved = keepLastAssociationLevelUnresolved;
    }
}