/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.terminology.dto;

/**
 * identifies a particular mapping. A CodeMap communicates that 1 or more codes from a particular
 * code system have been mapped to 1 or more codes of another particular code system.
 */
public class CodeMap implements java.io.Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * the unique name of the particular code map.
     */
    private java.lang.String mapName;

    /**
     * description of this mapping
     */
    private java.lang.String mapDescription;

    /**
     * the id of the source code system
     */
    private java.lang.String fromCodeSystemId;

    /**
     * the name of the source code system
     */
    private java.lang.String fromCodeSystemName;

    /**
     * the version of the source code system used in the map
     */
    private java.lang.String fromCodeSystemVersion;

    /**
     * the id of the target code system
     */
    private java.lang.String toCodeSystemId;

    /**
     * the name of the target code system
     */
    private java.lang.String toCodeSystemName;

    /**
     * the version of the target code system
     */
    private java.lang.String toCodeSystemVersion;

    public CodeMap() {}

    /**
     * Gets the map_name value for this CodeMap.
     *
     * @return map_name
     */
    public java.lang.String getMapName() {
        return mapName;
    }

    /**
     * Sets the map_name value for this CodeMap.
     *
     * @param mapName
     */
    public void setMapName(java.lang.String mapName) {
        this.mapName = mapName;
    }

    /**
     * Gets the mapDescription value for this CodeMap.
     *
     * @return mapDescription
     */
    public java.lang.String getMapDescription() {
        return mapDescription;
    }

    /**
     * Sets the mapDescription value for this CodeMap.
     *
     * @param mapDescription
     */
    public void setMapDescription(java.lang.String mapDescription) {
        this.mapDescription = mapDescription;
    }

    /**
     * Gets the fromCodeSystem_id value for this CodeMap.
     *
     * @return fromCodeSystem_id
     */
    public java.lang.String getFromCodeSystemId() {
        return fromCodeSystemId;
    }

    /**
     * Sets the fromCodeSystem_id value for this CodeMap.
     *
     * @param fromCodeSystemId
     */
    public void setFromCodeSystemId(java.lang.String fromCodeSystemId) {
        this.fromCodeSystemId = fromCodeSystemId;
    }

    /**
     * Gets the fromCodeSystem_name value for this CodeMap.
     *
     * @return fromCodeSystem_name
     */
    public java.lang.String getFromCodeSystemName() {
        return fromCodeSystemName;
    }

    /**
     * Sets the fromCodeSystem_name value for this CodeMap.
     *
     * @param fromCodeSystemName
     */
    public void setFromCodeSystemName(java.lang.String fromCodeSystemName) {
        this.fromCodeSystemName = fromCodeSystemName;
    }

    /**
     * Gets the fromCodeSystem_version value for this CodeMap.
     *
     * @return fromCodeSystem_version
     */
    public java.lang.String getFromCodeSystemVersion() {
        return fromCodeSystemVersion;
    }

    /**
     * Sets the fromCodeSystem_version value for this CodeMap.
     *
     * @param fromCodeSystemVersion
     */
    public void setFromCodeSystemVersion(java.lang.String fromCodeSystemVersion) {
        this.fromCodeSystemVersion = fromCodeSystemVersion;
    }

    /**
     * Gets the toCodeSystem_id value for this CodeMap.
     *
     * @return toCodeSystem_id
     */
    public java.lang.String getToCodeSystemId() {
        return toCodeSystemId;
    }

    /**
     * Sets the toCodeSystem_id value for this CodeMap.
     *
     * @param toCodeSystemId
     */
    public void setToCodeSystemId(java.lang.String toCodeSystemId) {
        this.toCodeSystemId = toCodeSystemId;
    }

    /**
     * Gets the toCodeSystem_name value for this CodeMap.
     *
     * @return toCodeSystem_name
     */
    public java.lang.String getToCodeSystemName() {
        return toCodeSystemName;
    }

    /**
     * Sets the toCodeSystem_name value for this CodeMap.
     *
     * @param toCodeSystemName
     */
    public void setToCodeSystemName(java.lang.String toCodeSystemName) {
        this.toCodeSystemName = toCodeSystemName;
    }

    /**
     * Gets the toCodeSystem_version value for this CodeMap.
     *
     * @return toCodeSystem_version
     */
    public java.lang.String getToCodeSystemVersion() {
        return toCodeSystemVersion;
    }

    /**
     * Sets the toCodeSystem_version value for this CodeMap.
     *
     * @param toCodeSystemVersion
     */
    public void setToCodeSystemVersion(java.lang.String toCodeSystemVersion) {
        this.toCodeSystemVersion = toCodeSystemVersion;
    }

    /**
     * @param codeSystemId
     * @param targetCodeSystem
     * @return
     */
    public boolean appliesTo(String sourceCodeSystem, String targetCodeSystem) {
        boolean sourceApplies = this.fromCodeSystemId.equals(sourceCodeSystem)
                || this.fromCodeSystemName.equals(sourceCodeSystem);
        boolean targetApplies = this.toCodeSystemId.equals(targetCodeSystem)
                || this.toCodeSystemName.equals(targetCodeSystem);
        return sourceApplies && targetApplies;
    }
}