/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.terminology.dto;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * Identifies a Code System and all the versions of this code system that are available.
 */
public class CodeSystemIdAndVersions implements java.io.Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * the unique code system identifier
     */
    private java.lang.String codeSystemId;

    /**
     * the official name of the code system
     */
    private java.lang.String codeSystemName;

    /**
     * copyright notice associated with code system, if any
     */
    private java.lang.String copyright;

    /**
     * the version or versions of the code system that are supported by this service. This list may
     * be empty if the code system doesn?t support individual version identifiers
     */
    private List<String> codeSystemVersions = new ArrayList<String>();

    public CodeSystemIdAndVersions() {}

    public CodeSystemIdAndVersions(java.lang.String codeSystemId, java.lang.String codeSystemName,
            java.lang.String copyright, java.lang.String[] codeSystemVersions) {
        this.codeSystemId = codeSystemId;
        this.codeSystemName = codeSystemName;
        this.copyright = copyright;
        this.codeSystemVersions = new ArrayList<String>(Arrays.asList(codeSystemVersions));
    }

    /**
     * Gets the codeSystem_id value for this CodeSystemIdAndVersions.
     *
     * @return codeSystem_id
     */
    public java.lang.String getCodeSystemId() {
        return codeSystemId;
    }

    /**
     * Sets the codeSystem_id value for this CodeSystemIdAndVersions.
     *
     * @param codeSystemId
     */
    public void setCodeSystemId(java.lang.String codeSystemId) {
        this.codeSystemId = codeSystemId;
    }

    /**
     * Gets the codeSystem_name value for this CodeSystemIdAndVersions.
     *
     * @return codeSystem_name
     */
    public java.lang.String getCodeSystemName() {
        return codeSystemName;
    }

    /**
     * Sets the codeSystem_name value for this CodeSystemIdAndVersions.
     *
     * @param codeSystemName
     */
    public void setCodeSystemName(java.lang.String codeSystemName) {
        this.codeSystemName = codeSystemName;
    }

    /**
     * Gets the copyright value for this CodeSystemIdAndVersions.
     *
     * @return copyright
     */
    public java.lang.String getCopyright() {
        return copyright;
    }

    /**
     * Sets the copyright value for this CodeSystemIdAndVersions.
     *
     * @param copyright
     */
    public void setCopyright(java.lang.String copyright) {
        this.copyright = copyright;
    }

    /**
     * Gets the codeSystem_versions value for this CodeSystemIdAndVersions.
     *
     * @return codeSystem_versions
     */
    public java.lang.String[] getCodeSystemVersions() {
        return codeSystemVersions.toArray(new String[codeSystemVersions.size()]);
    }

    /**
     * Sets the codeSystem_versions value for this CodeSystemIdAndVersions.
     *
     * @param codeSystemVersions
     */
    public void setCodeSystemVersions(java.lang.String[] codeSystemVersions) {
        this.codeSystemVersions = new ArrayList<String>(Arrays.asList(codeSystemVersions));
    }

    public void addVersion(String version) {
        this.codeSystemVersions.add(version);
    }

    @Override
    public String toString() {
        StringBuilder builder = new StringBuilder(this.codeSystemName);
        builder.append(" (");
        builder.append(this.codeSystemId);
        builder.append(") Versions ");
        builder.append(this.codeSystemVersions.toString());
        return builder.toString();
    }
}