/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.terminology.dto;

/**
 * More complete information about a code system.
 */
public class CodeSystemInfo implements java.io.Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * the code system id, name and supported version(s)
     */
    private CodeSystemIdAndVersions codeSystem;

    /**
     * the complete name of the code system
     */
    private java.lang.String fullName;

    /**
     * the description of the code system contents
     */
    private java.lang.String codeSystemDescription;

    /**
     * a list of all of the languages supported by the service for the code system. A "supported"
     * language is recognized by the code system and at least some of the concept designations or
     * properties are available in that language. All code systems must support at least one
     * language. While the service must list all of the primary language subtags that it supports,
     * it is optional whether it lists secondary languages. (i.e., if it supports "en-UK", it must
     * list "en" but may or may not list "en-UK"). The first language in the supportedLanguages list
     * is treated as the default language for the code system.
     */
    private java.lang.String[] supportedLanguages;

    /**
     * a list of all of the relationship codes supported by the service for the code system. A
     * "supported" relationship is recognized by the code system and the code system is able to
     * determine whether any two concept codes in the code system are or are not related to each
     * other under this relationship. A non-hierarchical code system doesn?t need to support any
     * relationships. Subsumption is represented by the hasSubtype relationship code
     */
    private java.lang.String[] supportedRelations;

    /**
     * a list of all of the properties supported by the service for the code system. A "supported"
     * property means that the code system recognizes the property and at least one coded concept is
     * associated with this property and an optional value.
     */
    private java.lang.String[] supportedProperties;

    /**
     * a list of the mime types supported by the code system. All code systems must support the
     * "text/plain" mime type, even if there are no properties associated with it.
     */
    private java.lang.String[] supportedMimeTypes;

    /**
     * a list of the mime types supported by the code system. All code systems must support the
     * "text/plain" mime type, even if there are no properties associated with it.
     */
    private java.lang.String[] supportedRelationQualifiers;

    public CodeSystemInfo() {}

    /**
     * Gets the codeSystem value for this CodeSystemInfo.
     *
     * @return codeSystem
     */
    public CodeSystemIdAndVersions getCodeSystem() {
        return codeSystem;
    }

    /**
     * Sets the codeSystem value for this CodeSystemInfo.
     *
     * @param codeSystem
     */
    public void setCodeSystem(CodeSystemIdAndVersions codeSystem) {
        this.codeSystem = codeSystem;
    }

    /**
     * Gets the fullName value for this CodeSystemInfo.
     *
     * @return fullName
     */
    public java.lang.String getFullName() {
        return fullName;
    }

    /**
     * Sets the fullName value for this CodeSystemInfo.
     *
     * @param fullName
     */
    public void setFullName(java.lang.String fullName) {
        this.fullName = fullName;
    }

    /**
     * Gets the codeSystemDescription value for this CodeSystemInfo.
     *
     * @return codeSystemDescription
     */
    public java.lang.String getCodeSystemDescription() {
        return codeSystemDescription;
    }

    /**
     * Sets the codeSystemDescription value for this CodeSystemInfo.
     *
     * @param codeSystemDescription
     */
    public void setCodeSystemDescription(java.lang.String codeSystemDescription) {
        this.codeSystemDescription = codeSystemDescription;
    }

    /**
     * Gets the supportedLanguages value for this CodeSystemInfo.
     *
     * @return supportedLanguages
     */
    public java.lang.String[] getSupportedLanguages() {
        return supportedLanguages;
    }

    /**
     * Sets the supportedLanguages value for this CodeSystemInfo.
     *
     * @param supportedLanguages
     */
    public void setSupportedLanguages(java.lang.String[] supportedLanguages) {
        this.supportedLanguages = supportedLanguages;
    }

    /**
     * Gets the supportedRelations value for this CodeSystemInfo.
     *
     * @return supportedRelations
     */
    public java.lang.String[] getSupportedRelations() {
        return supportedRelations;
    }

    /**
     * Sets the supportedRelations value for this CodeSystemInfo.
     *
     * @param supportedRelations
     */
    public void setSupportedRelations(java.lang.String[] supportedRelations) {
        this.supportedRelations = supportedRelations;
    }

    /**
     * Gets the supportedProperties value for this CodeSystemInfo.
     *
     * @return supportedProperties
     */
    public java.lang.String[] getSupportedProperties() {
        return supportedProperties;
    }

    /**
     * Sets the supportedProperties value for this CodeSystemInfo.
     *
     * @param supportedProperties
     */
    public void setSupportedProperties(java.lang.String[] supportedProperties) {
        this.supportedProperties = supportedProperties;
    }

    /**
     * Gets the supportedMimeTypes value for this CodeSystemInfo.
     *
     * @return supportedMimeTypes
     */
    public java.lang.String[] getSupportedMimeTypes() {
        return supportedMimeTypes;
    }

    /**
     * Sets the supportedMimeTypes value for this CodeSystemInfo.
     *
     * @param supportedMimeTypes
     */
    public void setSupportedMimeTypes(java.lang.String[] supportedMimeTypes) {
        this.supportedMimeTypes = supportedMimeTypes;
    }

    /**
     * Gets the supportedRelationQualifiers value for this CodeSystemInfo.
     *
     * @return supportedRelationQualifiers
     */
    public java.lang.String[] getSupportedRelationQualifiers() {
        return supportedRelationQualifiers;
    }

    /**
     * Sets the supportedRelationQualifiers value for this CodeSystemInfo.
     *
     * @param supportedRelationQualifiers
     */
    public void setSupportedRelationQualifiers(java.lang.String[] supportedRelationQualifiers) {
        this.supportedRelationQualifiers = supportedRelationQualifiers;
    }

}