/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.terminology.dto;

/**
 * Complete information about a concept.
 */
public class CompleteCodedConceptDescription implements java.io.Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * the code system identifier and concept code being retrieved
     */
    private ConceptId conceptId;

    /**
     * the status of the concept in the given code system version.
     */
    private java.lang.String conceptStatusCode;

    /**
     * the version of the code system that the description was drawn from
     */
    private java.lang.String codeSystemVersion;

    /**
     * a list of all of the designations for the coded concept.
     */
    private ConceptDesignation[] designatedBy;

    /**
     * a list of all of the properties of the coded concept excluding the ConceptDesignation
     * properties.
     */
    private ConceptProperty[] hasProperties;

    /**
     * a list of all of the relationships in which this concept plays the role of "source".
     */
    private ConceptRelationship[] sourceFor;

    /**
     * a list of all of the relationships in which this concept plays the role of "source".
     */
    private ConceptRelationship[] targetOf;

    public CompleteCodedConceptDescription() {}

    public CompleteCodedConceptDescription(ConceptId conceptId, java.lang.String conceptStatusCode,
            java.lang.String codeSystemVersion, ConceptDesignation[] designatedBy,
            ConceptProperty[] hasProperties, ConceptRelationship[] sourceFor,
            ConceptRelationship[] targetOf) {
        this.conceptId = conceptId;
        this.conceptStatusCode = conceptStatusCode;
        this.codeSystemVersion = codeSystemVersion;
        this.designatedBy = designatedBy;
        this.hasProperties = hasProperties;
        this.sourceFor = sourceFor;
        this.targetOf = targetOf;
    }

    /**
     * Gets the concept_id value for this CompleteCodedConceptDescription.
     *
     * @return concept_id
     */
    public ConceptId getConceptId() {
        return conceptId;
    }

    /**
     * Sets the concept_id value for this CompleteCodedConceptDescription.
     *
     * @param conceptId
     */
    public void setConceptId(ConceptId conceptId) {
        this.conceptId = conceptId;
    }

    /**
     * Gets the conceptStatus_code value for this CompleteCodedConceptDescription.
     *
     * @return conceptStatus_code
     */
    public java.lang.String getConceptStatusCode() {
        return conceptStatusCode;
    }

    /**
     * Sets the conceptStatus_code value for this CompleteCodedConceptDescription.
     *
     * @param conceptStatusCode
     */
    public void setConceptStatusCode(java.lang.String conceptStatusCode) {
        this.conceptStatusCode = conceptStatusCode;
    }

    /**
     * Gets the codeSystem_version value for this CompleteCodedConceptDescription.
     *
     * @return codeSystem_version
     */
    public java.lang.String getCodeSystemVersion() {
        return codeSystemVersion;
    }

    /**
     * Sets the codeSystem_version value for this CompleteCodedConceptDescription.
     *
     * @param codeSystemVersion
     */
    public void setCodeSystemVersion(java.lang.String codeSystemVersion) {
        this.codeSystemVersion = codeSystemVersion;
    }

    /**
     * Gets the designatedBy value for this CompleteCodedConceptDescription.
     *
     * @return designatedBy
     */
    public ConceptDesignation[] getDesignatedBy() {
        return designatedBy;
    }

    /**
     * Sets the designatedBy value for this CompleteCodedConceptDescription.
     *
     * @param designatedBy
     */
    public void setDesignatedBy(ConceptDesignation[] designatedBy) {
        this.designatedBy = designatedBy;
    }

    /**
     * Gets the hasProperties value for this CompleteCodedConceptDescription.
     *
     * @return hasProperties
     */
    public ConceptProperty[] getHasProperties() {
        return hasProperties;
    }

    /**
     * Sets the hasProperties value for this CompleteCodedConceptDescription.
     *
     * @param hasProperties
     */
    public void setHasProperties(ConceptProperty[] hasProperties) {
        this.hasProperties = hasProperties;
    }

    /**
     * Gets the sourceFor value for this CompleteCodedConceptDescription.
     *
     * @return sourceFor
     */
    public ConceptRelationship[] getSourceFor() {
        return sourceFor;
    }

    /**
     * Sets the sourceFor value for this CompleteCodedConceptDescription.
     *
     * @param sourceFor
     */
    public void setSourceFor(ConceptRelationship[] sourceFor) {
        this.sourceFor = sourceFor;
    }

    /**
     * Gets the targetOf value for this CompleteCodedConceptDescription.
     *
     * @return targetOf
     */
    public ConceptRelationship[] getTargetOf() {
        return targetOf;
    }

    /**
     * Sets the targetOf value for this CompleteCodedConceptDescription.
     *
     * @param targetOf
     */
    public void setTargetOf(ConceptRelationship[] targetOf) {
        this.targetOf = targetOf;
    }
}