/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.terminology.dto;

/**
 * Info about a relationship between two concepts
 */
public class ConceptRelationship implements java.io.Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * the concept identifier (code system id and concept code) of the source concept in the
     * relationship.
     */
    private ConceptId sourceConceptId;

    /**
     * the relationship code
     */
    private java.lang.String relationshipCode;

    /**
     * an optional list of qualifier codes that further refine or otherwise qualify the relationship
     * entry.
     */
    private java.lang.String[] relationQualifiers;

    /**
     * concept identifier (code system id and concept code) of the target of the relationship.
     */
    private ConceptId targetConceptId;

    public ConceptRelationship() {}

    public ConceptRelationship(ConceptId sourceConceptId, java.lang.String relationshipCode,
            java.lang.String[] relationQualifiers, ConceptId targetConceptId) {
        this.sourceConceptId = sourceConceptId;
        this.relationshipCode = relationshipCode;
        this.relationQualifiers = relationQualifiers;
        this.targetConceptId = targetConceptId;
    }

    /**
     * Gets the sourceConcept_id value for this ConceptRelationship.
     *
     * @return sourceConcept_id
     */
    public ConceptId getSourceConceptId() {
        return sourceConceptId;
    }

    /**
     * Sets the sourceConcept_id value for this ConceptRelationship.
     *
     * @param sourceConceptId
     */
    public void setSourceConceptId(ConceptId sourceConceptId) {
        this.sourceConceptId = sourceConceptId;
    }

    /**
     * Gets the relationship_code value for this ConceptRelationship.
     *
     * @return relationship_code
     */
    public java.lang.String getRelationshipCode() {
        return relationshipCode;
    }

    /**
     * Sets the relationship_code value for this ConceptRelationship.
     *
     * @param relationshipCode
     */
    public void setRelationshipCode(java.lang.String relationshipCode) {
        this.relationshipCode = relationshipCode;
    }

    /**
     * Gets the relationQualifiers value for this ConceptRelationship.
     *
     * @return relationQualifiers
     */
    public java.lang.String[] getRelationQualifiers() {
        return relationQualifiers;
    }

    /**
     * Sets the relationQualifiers value for this ConceptRelationship.
     *
     * @param relationQualifiers
     */
    public void setRelationQualifiers(java.lang.String[] relationQualifiers) {
        this.relationQualifiers = relationQualifiers;
    }

    /**
     * Gets the targetConcept_id value for this ConceptRelationship.
     *
     * @return targetConcept_id
     */
    public ConceptId getTargetConceptId() {
        return targetConceptId;
    }

    /**
     * Sets the targetConcept_id value for this ConceptRelationship.
     *
     * @param targetConceptId
     */
    public void setTargetConceptId(ConceptId targetConceptId) {
        this.targetConceptId = targetConceptId;
    }

}