/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.terminology.dto;

public class RelatedCode implements java.io.Serializable {

    private static final long serialVersionUID = 1L;

/**
     * an integer that defines the distance from the codeToExpand in hops. The root node will always
     * have a path length of 0.
     */
private short pathLength;

    /**
     * related concept code
     */
    private java.lang.String conceptCode;

    /**
     * the preferred designation for code in the appropriate language and usage context, or the
     * default designation if none is stated explicitly as being preferred
     */
    private java.lang.String designation;

    /**
     * list of relationship qualifiers that apply to this node
     */
    private java.lang.String[] relationQualifiers;

    /**
     * TRUE means that there are additional concept codes directly related to concept_code that can
     * be further expanded.
     */
    private boolean canExpand;

    /**
     * if canExpand is true, this field contains an opaque context that can be used to further
     * expand the code in this node.
     */
    private byte[] expansionContext;

    public RelatedCode() {}

    public RelatedCode(short pathLength, java.lang.String conceptCode,
            java.lang.String designation, java.lang.String[] relationQualifiers, boolean canExpand,
            byte[] expansionContext) {
        this.pathLength = pathLength;
        this.conceptCode = conceptCode;
        this.designation = designation;
        this.relationQualifiers = relationQualifiers;
        this.canExpand = canExpand;
        this.expansionContext = expansionContext;
    }

    /**
     * Gets the pathLength value for this RelatedCode.
     *
     * @return pathLength
     */
    public short getPathLength() {
        return pathLength;
    }

    /**
     * Sets the pathLength value for this RelatedCode.
     *
     * @param pathLength
     */
    public void setPathLength(short pathLength) {
        this.pathLength = pathLength;
    }

    /**
     * Gets the concept_code value for this RelatedCode.
     *
     * @return concept_code
     */
    public java.lang.String getConceptCode() {
        return conceptCode;
    }

    /**
     * Sets the concept_code value for this RelatedCode.
     *
     * @param conceptCode
     */
    public void setConceptCode(java.lang.String conceptCode) {
        this.conceptCode = conceptCode;
    }

    /**
     * Gets the designation value for this RelatedCode.
     *
     * @return designation
     */
    public java.lang.String getDesignation() {
        return designation;
    }

    /**
     * Sets the designation value for this RelatedCode.
     *
     * @param designation
     */
    public void setDesignation(java.lang.String designation) {
        this.designation = designation;
    }

    /**
     * Gets the relationQualifiers value for this RelatedCode.
     *
     * @return relationQualifiers
     */
    public java.lang.String[] getRelationQualifiers() {
        return relationQualifiers;
    }

    /**
     * Sets the relationQualifiers value for this RelatedCode.
     *
     * @param relationQualifiers
     */
    public void setRelationQualifiers(java.lang.String[] relationQualifiers) {
        this.relationQualifiers = relationQualifiers;
    }

    /**
     * Gets the canExpand value for this RelatedCode.
     *
     * @return canExpand
     */
    public boolean isCanExpand() {
        return canExpand;
    }

    /**
     * Sets the canExpand value for this RelatedCode.
     *
     * @param canExpand
     */
    public void setCanExpand(boolean canExpand) {
        this.canExpand = canExpand;
    }

    /**
     * Gets the expansionContext value for this RelatedCode.
     *
     * @return expansionContext
     */
    public byte[] getExpansionContext() {
        return expansionContext;
    }

    /**
     * Sets the expansionContext value for this RelatedCode.
     *
     * @param expansionContext
     */
    public void setExpansionContext(byte[] expansionContext) {
        this.expansionContext = expansionContext;
    }

}