/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.terminology.exceptions;

public class UnexpectedError extends RuntimeException {

/**
     * An error that could not be anticipated by the specification has occurred. This includes
     * things like memory faults, I/O errors, database access errors and any other sort of
     * unexpected event that prevents successful completion of the API call. possible_cause can
     * carry a more detailed description of what actually occurred.
     */
private static final long serialVersionUID = 1L;

    private java.lang.String possibleCause;

    public UnexpectedError() {}

    public UnexpectedError(java.lang.String possibleCause) {
        this.possibleCause = possibleCause;
    }

    public UnexpectedError(Exception cause) {
    	super(cause);
    	this.possibleCause = cause.getMessage();
    }

    /**
     * Gets the possible_cause value for this UnexpectedError.
     *
     * @return possible_cause
     */
    public java.lang.String getPossibleCause() {
        return possibleCause;
    }

    /**
     * Sets the possible_cause value for this UnexpectedError.
     *
     * @param possibleCause
     */
    public void setPossibleCause(java.lang.String possibleCause) {
        this.possibleCause = possibleCause;
    }
}