/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.terminology.impl.exceptions;

import java.util.List;

import org.lexgrid.extension.cts.terminology.exceptions.UnexpectedError;

/**
 * Utility for common Exception tasks
 */
public final class ExceptionUtil {

    private ExceptionUtil() {}

    /**
     * Have all {@link ExceptionHandler}s attempt to handle the exception. Using method injection
     * for the handlers allows different components to inject their own desired set of handlers.
     * Having this task in a utility class such as this allows multiple components to reuse the same
     * code.
     *
     * @param e
     * @param list
     */
    public static <T extends Exception> void handle(T e, List<ExceptionHandler<T>> list) {

        boolean wasHandled = false;

        for (ExceptionHandler<T> exceptionHandler : list) {
            if (exceptionHandler.supports(e)) {
                exceptionHandler.handle(e);
                wasHandled = true;
            }
        }
        if (!wasHandled) {
            throw new UnexpectedError(e);
        }
    }

}