/*
 * Copyright: (c) 2004-2009 Mayo Foundation for Medical Education and 
 * Research (MFMER). All rights reserved. MAYO, MAYO CLINIC, and the
 * triple-shield Mayo logo are trademarks and service marks of MFMER.
 *
 * Except as contained in the copyright notice above, or as used to identify 
 * MFMER as the author of this software, the trade names, trademarks, service
 * marks, or product names of the copyright holder shall not be used in
 * advertising, promotion or otherwise in connection with this software without
 * prior written authorization of the copyright holder.
 * 
 * Licensed under the Eclipse Public License, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * 		http://www.eclipse.org/legal/epl-v10.html
 * 
 */
package org.lexgrid.extension.cts.terminology.impl.exceptions;

import org.LexGrid.LexBIG.Exceptions.LBParameterException;
import org.lexgrid.extension.cts.lexevs.util.template.exceptions.LexEvsParameterException;
import org.lexgrid.extension.cts.terminology.exceptions.UnknownCodeSystem;
import org.lexgrid.extension.cts.terminology.exceptions.UnknownLanguageCode;

/**
 * Converts wrapped {@link LBParameterException}s to the appropriate CTS Exceptions. TODO: Just as
 * soon as we need to add more parameters to this, use the state pattern and composite pattern. A
 * handler for each parameter. A map here populated with those handlers, keyed by the parameter
 * names.
 */
public class LexEvsParameterExceptionHandler implements ExceptionHandler<LexEvsParameterException> {

    public static final String LANGUAGE_PARAMETER_NAME = "Language";
    public static final String CODING_SCHEME_PARAMETER_NAME = "codingSchemeName";
    public static final String CODING_SCHEME_AND_VERSION_PARAMETER_NAME = "codingSchemeName, version";


    /*
     * (non-Javadoc)
     *
     * @see com.gehc.ce.terminology.cts.impl.exceptions.ExceptionHandler#handle(java.lang.Exception)
     */
    @Override
    public void handle(LexEvsParameterException e) {

        LBParameterException checkedException = e.getCheckedException();

        if (LANGUAGE_PARAMETER_NAME.equals(checkedException.getParameterName())) {
            throw new UnknownLanguageCode(checkedException.getParameterValue());
        }

        if (CODING_SCHEME_PARAMETER_NAME.equals(checkedException.getParameterName())) {
            throw new UnknownCodeSystem(checkedException.getParameterValue());
        }

        if (CODING_SCHEME_AND_VERSION_PARAMETER_NAME.equals(checkedException.getParameterName())) {
            throw new UnknownCodeSystem(checkedException.getParameterValue());
        }
    }

    /*
     * (non-Javadoc)
     *
     * @see
     * com.gehc.ce.terminology.cts.impl.exceptions.ExceptionHandler#supports(java.lang.Exception)
     */
    @Override
    public boolean supports(Exception e) {
        return e instanceof LexEvsParameterException;
    }

}